
<hr>
<p align="center">
<img src="https://github.com/eseunghwan/mapsi.py/blob/master/mapsi/assets/mapsi_big.png?raw=true" width=400 />
<br>
MVVM UI Framework for Python and Brython
<br>
<a href="https://pypi.python.org/pypi/mapsipy"><image src="https://img.shields.io/pypi/v/mapsipy.svg" /></a>
<a href="https://travis-ci.com/eseunghwan/mapsi"><image src="https://img.shields.io/travis/eseunghwan/mapsipy.svg" /></a>
<a href="https://mapsipy.readthedocs.io/en/latest/?version=latest"><image src="https://readthedocs.org/projects/mapsipy/badge/?version=latest" alt="Documentation Status" /></a>
</p>
<hr>

<br><br>

# Install
## using pip(stable)
```powershell
pip3 install mapsipy
```
## using git(dev)
```powershell
pip3 install https://github.com/eseunghwan/pyvuejs.git
```
<br><br>

# Usage
### create project with cli
```powershell
mapsipy-cli init [dest]
```
<br>

### run with server
```powershell
mapsipy-cli serve
```
<br>

### build project file to standalone .html and .js
```powershell
mapsipy-cli build [dest]
```
<br><br>

# TODO
[ ] classified virtual dom<br>
[ ] classified viewmodel
